# Changelog

## 0.1.0-alpha.3 (2024-10-14)

Full Changelog: [v0.1.0-alpha.2...v0.1.0-alpha.3](https://github.com/scaleapi/agents-python/compare/v0.1.0-alpha.2...v0.1.0-alpha.3)

### Features

* **api:** api update ([#15](https://github.com/scaleapi/agents-python/issues/15)) ([391e8ed](https://github.com/scaleapi/agents-python/commit/391e8ed1a2775a2751f09b2880b8aef345943231))
* **api:** api update ([#17](https://github.com/scaleapi/agents-python/issues/17)) ([0dbd546](https://github.com/scaleapi/agents-python/commit/0dbd54672a4c3e1602f81c62f0218b521ce7a97e))
* **api:** api update ([#18](https://github.com/scaleapi/agents-python/issues/18)) ([903c321](https://github.com/scaleapi/agents-python/commit/903c321f4802082abe02146317fcfb1889b6a25d))
* **api:** api update ([#19](https://github.com/scaleapi/agents-python/issues/19)) ([5e54a2a](https://github.com/scaleapi/agents-python/commit/5e54a2a77f61fae9b94f7c515b9e18e7ce62d804))
* **api:** api update ([#20](https://github.com/scaleapi/agents-python/issues/20)) ([1bc9466](https://github.com/scaleapi/agents-python/commit/1bc94666d1e20ee7b9791de52eda04d042a80d6e))
* **api:** api update ([#21](https://github.com/scaleapi/agents-python/issues/21)) ([617dfd5](https://github.com/scaleapi/agents-python/commit/617dfd5455f0b438f285d11cd07dfbf331939ba2))


### Bug Fixes

* **internal:** handle recursive imports ([9ce182d](https://github.com/scaleapi/agents-python/commit/9ce182dce282232c8030b29c04df0d580627dbfc))

## 0.1.0-alpha.2 (2024-10-04)

Full Changelog: [v0.0.1-alpha.1...v0.1.0-alpha.2](https://github.com/scaleapi/agents-python/compare/v0.0.1-alpha.1...v0.1.0-alpha.2)

### Features

* **api:** OpenAPI spec update via Stainless API ([#12](https://github.com/scaleapi/agents-python/issues/12)) ([d2e8255](https://github.com/scaleapi/agents-python/commit/d2e825504368f072deb458f2ba4e43fa90d09437))
* **api:** OpenAPI spec update via Stainless API ([#7](https://github.com/scaleapi/agents-python/issues/7)) ([8062fc7](https://github.com/scaleapi/agents-python/commit/8062fc7d4b5b17ad87ac7616501aa40b57489fad))


### Bug Fixes

* **types:** deduplicate node item ([#11](https://github.com/scaleapi/agents-python/issues/11)) ([20b087c](https://github.com/scaleapi/agents-python/commit/20b087cfb9d2b5441dd20d06b32b8508bc6b0a98))


### Chores

* **internal:** add support for parsing bool response content ([#13](https://github.com/scaleapi/agents-python/issues/13)) ([3926753](https://github.com/scaleapi/agents-python/commit/39267530e828faaf20f9243c14fdbe56d080be42))
* **internal:** codegen related update ([#10](https://github.com/scaleapi/agents-python/issues/10)) ([551ba45](https://github.com/scaleapi/agents-python/commit/551ba45eff20663ea38219848f6b9ee6c8a66f1b))
* **internal:** codegen related update ([#8](https://github.com/scaleapi/agents-python/issues/8)) ([dd91cac](https://github.com/scaleapi/agents-python/commit/dd91cac1d451c2ae3e93d10de5d077704e25fa42))
* **internal:** codegen related update ([#9](https://github.com/scaleapi/agents-python/issues/9)) ([813e413](https://github.com/scaleapi/agents-python/commit/813e4135ffd411983bcfdd3c153539b165e6383d))
* update SDK settings ([#5](https://github.com/scaleapi/agents-python/issues/5)) ([2535b0c](https://github.com/scaleapi/agents-python/commit/2535b0cf1de9ee6c1681de30d7d812fee4fd4abd))

## 0.0.1-alpha.1 (2024-08-28)

Full Changelog: [v0.0.1-alpha.0...v0.0.1-alpha.1](https://github.com/scaleapi/agents-python/compare/v0.0.1-alpha.0...v0.0.1-alpha.1)

### Chores

* go live ([#1](https://github.com/scaleapi/agents-python/issues/1)) ([b1c9aa6](https://github.com/scaleapi/agents-python/commit/b1c9aa6639e9e1105b4f336cb7c9ff450dc5a9b4))
* update SDK settings ([#3](https://github.com/scaleapi/agents-python/issues/3)) ([139dd33](https://github.com/scaleapi/agents-python/commit/139dd33d0d444f47ce2b597491892cd9d9efd3c8))
